OC.L10N.register(
    "oauth2",
    {
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Vaša URL pre presmerovanie musí byť úplná. Napríklad: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Povoliť overenie kompatibilné s OAuth2 iných webových aplikácií.",
    "OAuth 2.0 clients" : "klienti OAuth 2.0",
    "Name" : "Názov",
    "Redirection URI" : "URI presmerovania",
    "Client Identifier" : "Identifikátor klienta",
    "Secret" : "Tajný kľúč",
    "Add client" : "Pridať klienta",
    "Add" : "Pridať",
    "Delete" : "Zmazať"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
